Constructs an edge list representing the three-layer cascade network from a single row of cascade survey parameters. Layer 1 nodes form a fully connected clique; Layer 2 nodes are connected to their Layer 1 parents with probabilistic cross-connections; Layer 3 nodes are connected to their Layer 2 parents with probabilistic cross-connections. Probabilistic back-edges between layers are also generated.
Value
A data frame with columns from, to, and layer,
suitable for passing directly to calculate_cascade().
See also
analyze_cascade which calls this function internally.